@@ -88,9 +88,9 @@ class BuildExtension(build_ext):
         if shutil.which("cmake") is None:
             raise RuntimeError("Required command 'cmake' not found")
 
-        # Check that Ninja is installed
-        if shutil.which("ninja") is None:
-            raise RuntimeError("Required command 'ninja' not found")
+        # # Check that Ninja is installed
+        # if shutil.which("ninja") is None:
+        #     raise RuntimeError("Required command 'ninja' not found")
 
         for ext in cmake_extensions:
 
@@ -161,7 +161,7 @@ class BuildExtension(build_ext):
         # CMake build arguments
         build_args = [
                 "--config", ext.cmake_build_type
-        ]
+        ] + ext.cmake_build_options
         if self.parallel:
             build_args.append(f"-j{self.parallel}")
 
@@ -205,7 +205,7 @@ class BuildExtension(build_ext):
         build_command = ["cmake", "--build", build_folder] + build_args
 
         # 3. Compose CMake install command
-        install_command = ["cmake", "--install", build_folder]
+        install_command = ["cmake", "--install", build_folder] + ext.cmake_install_options
 
         # If the cmake_component option of the CMakeExtension is used, install just
         # the specified component.
